#include <esp_now.h>
#include <WiFi.h>
#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>

Adafruit_BME280 bme;          // I2C
uint8_t recvAddress[] = {0x24, 0x62, 0xAB, 0xCA, 0x55, 0xCC};

typedef struct {
  char  myname[8] = "BME280 ";
  float temperature;
  float humidity;
  float pressure;
} struct_message;

struct_message message;
esp_now_peer_info_t peerInfo;
unsigned long lastMsg;

void data_sent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.print("\r\nStatus of Last Message Sent:\t");
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? "Delivery Success" : "Delivery Fail");
}

void setup() {
  Serial.begin(115200);
  unsigned status = bme.begin(0x76, &Wire);
  if (!status) {
    Serial.println("Could not find a valid BME280 sensor, check wiring, address, sensor ID!");
    Serial.print("SensorID was: 0x"); Serial.println(bme.sensorID(), 16);
    Serial.print("        ID of 0xFF probably means a bad address, a BMP 180 or BMP 085\n");
    Serial.print("   ID of 0x56-0x58 represents a BMP 280,\n");
    Serial.print("        ID of 0x60 represents a BME 280.\n");
    Serial.print("        ID of 0x61 represents a BME 680.\n");
    while (1) delay(10);
  }

  WiFi.mode(WIFI_STA);
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }
  esp_now_register_send_cb(data_sent);
  memcpy(peerInfo.peer_addr, recvAddress, 6);
  peerInfo.channel = 0;
  peerInfo.encrypt = false;
  if (esp_now_add_peer(&peerInfo) != ESP_OK) {
    Serial.println("Failed to add peer");
    return;
  }
}

void loop() {
  if ((millis() - lastMsg) > 5000) {
    message.temperature = bme.readTemperature();
    message.humidity = bme.readHumidity();
    message.pressure = bme.readPressure() / 98.58566F;
    esp_err_t outcome = esp_now_send(recvAddress, (uint8_t *) &message, sizeof(message));
    if (outcome == ESP_OK) { Serial.println("Mesage sent successfully!"); }
    else { Serial.println("Error sending the message"); }
    lastMsg += 5000;
  }
}
