#include <ESP8266WiFi.h>
#include <espnow.h>
#include "DHT.h"

#define DHTPIN 14       // GPIO14 (D5) pin for DHT sensor
DHT dht(DHTPIN, DHT22);

uint8_t recvAddress[] = {0x24, 0x62, 0xAB, 0xCA, 0x55, 0xCC};

typedef struct {
  char  myname[8] = "*DHT22*";
  float temperature;
  float humidity;
  float pressure=0.0f;
} struct_message;

struct_message message;
unsigned long lastMsg;

void onSent(uint8_t *mac_addr, uint8_t sendStatus) {
  Serial.print("Status:");
  Serial.println(sendStatus);
}

void setup() {
  Serial.begin(115200);
  dht.begin();
  WiFi.mode(WIFI_STA);
  if (esp_now_init() != 0) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }
  esp_now_set_self_role(ESP_NOW_ROLE_CONTROLLER);
  esp_now_add_peer(recvAddress, ESP_NOW_ROLE_SLAVE, 1, NULL, 0);  
  esp_now_register_send_cb(onSent);
}

void loop() {
  if ((millis() - lastMsg) > 5000) {
    message.temperature = dht.readTemperature();
    message.humidity = dht.readHumidity();
    int outcome = esp_now_send(NULL, (uint8_t *) &message, sizeof(message));
    if (outcome == 0) { Serial.println("Mesage sent successfully!"); }
    else { Serial.println("Error sending the message"); }
    lastMsg += 5000;
  }
}
